@@ -57,7 +57,7 @@ class Command(BaseCommand):
                 hashData = hashlib.md5(
                         toBytes("%s %s" % (command, time))).hexdigest()
                         
-                jobName = "%s%s" % (command.split()[0], hashData)
+                jobName = "%s_%s" % (command.split()[0], hashData)
             else:
                 # 判斷 command
                 if not command.split()[0] in get_commands():
@@ -79,10 +79,6 @@ class Command(BaseCommand):
             
             shell = temp.render(c).replace("\r\n", "\n")
             
-            # 不知為何 "'" 被 render 成 "&#39;"，
-            # 因此將所有檔案中的 "&#39;" replace 回來
-            shell = shell.replace("&#39;", "'")
-            
             with open("%s.sh" % jobName, 'w') as f:
                 f.write(shell)
             
