@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11842 2020-01-07 13:51:23Z Lavender $
+# $Id: __init__.py 11852 2020-01-08 13:23:04Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-01-07 22:51:23 +0900 (週二, 07 一月 2020) $
-# $Revision: 11842 $
+# $Date: 2020-01-08 22:23:04 +0900 (週三, 08 一月 2020) $
+# $Revision: 11852 $
 
 import os
 import sys
@@ -187,6 +187,8 @@ def attachSettings(settingsDict, enablePaypal=False):
     
     ADDING_INSTALLED_APPS += (
         'Iuno.shop',
+        'Iuno.shop.promotions',
+        'Iuno.shop.dashboard_promotions',
         'ckeditor',
         'ckeditor_uploader',
     )
@@ -560,7 +562,33 @@ def attachSettings(settingsDict, enablePaypal=False):
     #=========================================================================
     
     #=========================================================================
-    
+    # promotions
+    DEFAULT_PROMOTION_SETTINGS = {
+        'OSCAR_PROMOTION_FOLDER': 'images/promotions/',
+        'OSCAR_PROMOTION_POSITIONS': (
+            ('page', 'Page'),
+            ('right', 'Right-hand sidebar'),
+            ('left', 'Left-hand sidebar')
+        ),
+        'OSCAR_PROMOTIONS_ENABLED': True,
+    }
+    update(settingsDict, DEFAULT_PROMOTION_SETTINGS)
+
+    # 用來加 dashboard 頁面，把 promotion 加到跟 page 同個 Tab 下
+    for s in settingsDict['OSCAR_DASHBOARD_NAVIGATION']:
+        addUrl = False
+        for child in s.get('children', []):
+            if child.get('url_name') == 'dashboard:page-list':
+                addUrl = True
+        if addUrl:
+            s['children'].append({
+                'label': _('Content blocks'),
+                'url_name': 'promotion-list',
+            })
+            s['children'].append({
+                'label': _('Content blocks by page'),
+                'url_name': 'promotion-list-by-page',
+            })
     
     
 
