@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 11793 2019-12-11 15:00:31Z Lavender $
+# $Id: forms.py 11802 2019-12-17 16:04:02Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-12-12 00:00:31 +0900 (週四, 12 十二月 2019) $
-# $Revision: 11793 $
+# $Date: 2019-12-18 01:04:02 +0900 (週三, 18 十二月 2019) $
+# $Revision: 11802 $
 
 import os
 import re
@@ -615,7 +615,7 @@ class BonusSettingsForm(forms.ModelForm):
     class Meta:
         model = BonusSettings
         fields = ['consumption', 'percent', 'discount', 
-                  'limit', 'includeRange', 'excludeRange']
+                  'limit', 'receiveStatus', 'includeRange', 'excludeRange']
         
 class BonusForm(forms.Form):
     quantity = forms.IntegerField(
