@@ -9,8 +9,10 @@ from django.contrib.auth import get_user_model
 from django.conf import settings
 from django.utils import timezone
 from django.core.validators import MaxValueValidator, MinValueValidator
+from django.template import TemplateDoesNotExist, engines
 from django.utils.translation import gettext_lazy as _
 from solo.models import SingletonModel
+from django.template.loader import get_template
 from oscar.core.loading import get_model
 
 User = get_user_model()
@@ -203,7 +205,7 @@ class BonusRecord(models.Model):
         verbose_name=_("Use"), default=0)
     receive = models.PositiveIntegerField(
         verbose_name=_("Receive"), default=0)
-    adjust = models.PositiveIntegerField(
+    adjust = models.IntegerField(
         verbose_name=_("Adjust"), default=0)
         
     createdTime = models.DateTimeField(_("Created Time"), auto_now_add=True)
@@ -281,6 +283,87 @@ class BonusSettings(SingletonModel):
         related_name='bonusExcludeRange'
     )
     
+# https://code.nuwainfo.com/trac/Mercurius/ticket/3301#ticket
+from oscar.apps.customer.managers import CommunicationTypeManager
+CommunicationEventType = get_model('customer', 'CommunicationEventType')
+RawHTML = get_model('promotions', 'RawHTML')
+
+def getATMInfo():
+    bank, created = RawHTML.objects.get_or_create(
+        name='ATM Bank ID',
+        defaults={
+            'body': '<p>XXX</p>',
+        }
+    )
+    account, created = RawHTML.objects.get_or_create(
+        name='ATM Account',
+        defaults={
+            'body': '<p>XXXXXXXXXXXXX</p>',
+        }
+    )
+    return (bank, account)
+
+def get_messages(self, ctx=None):
+    """
+    Return a dict of templates with the context merged in
+
+    We look first at the field templates but fail over to
+    a set of file templates that follow a conventional path.
+    """
+    code = self.code.lower()
+    
+    # Build a dict of message name to Template instances
+    templates = {'subject': 'email_subject_template',
+                 'body': 'email_body_template',
+                 'html': 'email_body_html_template',
+                 'sms': 'sms_template'}
+    for name, attr_name in templates.items():
+        field = getattr(self, attr_name, None)
+        
+        if field is not None:
+            # Template content is in a model field
+            templates[name] = engines['django'].from_string(field)
+        else:
+            # Model field is empty - look for a file template
+            template_name = getattr(self, "%s_file" % attr_name) % code
+            
+            try:
+                templates[name] = get_template(template_name)
+            except TemplateDoesNotExist:
+                templates[name] = None
+
+    # Pass base URL for serving images within HTML emails
+    if ctx is None:
+        ctx = {}
+        
+    if code == 'order_placed':
+        bank, account = getATMInfo()
+        ctx['bank'] = bank
+        ctx['account'] = account
+       
+    ctx['static_base_url'] = getattr(
+        settings, 'OSCAR_STATIC_BASE_URL', None)
+
+    messages = {}
+    for name, template in templates.items():
+        messages[name] = template.render(ctx) if template else ''
+
+    # Ensure the email subject doesn't contain any newlines
+    messages['subject'] = messages['subject'].replace("\n", "")
+    messages['subject'] = messages['subject'].replace("\r", "")
+
+    return messages
+
+# class CommunicationTypeManager2(CommunicationTypeManager):
+    # def get_and_render(self, code, context):
+        # print("ABC")
+        # try:
+            # commtype = self.get(code=code)
+        # except self.model.DoesNotExist:
+            # commtype = self.model(code=code)
+        # return commtype.get_messages(context)
+        
+CommunicationEventType.get_messages = get_messages
     
 class ECPayTrade(models.Model):
     merchantId = models.CharField(max_length=255)
