@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11826 2020-01-01 08:07:12Z Lavender $
+# $Id: views.py 11852 2020-01-08 13:23:04Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-01-01 17:07:12 +0900 (週三, 01 一月 2020) $
-# $Revision: 11826 $ 
+# $Date: 2020-01-08 22:23:04 +0900 (週三, 08 一月 2020) $
+# $Revision: 11852 $ 
 
 import json
 import logging
@@ -58,7 +58,7 @@ from Iuno.shop import buildAPIForm
 from Iuno.shop.models import (
     ECPayTrade, AllPayTrade, SpgatewayTrade, CathaybkCreditTrade,
     ECPayLogisticTrade, OrderOrdererAddress, OrdererAddress, 
-    BonusSettings, BonusRecord, Bonus, calcReceiveBouns)
+    BonusSettings, BonusRecord, Bonus, calcReceiveBouns, getATMInfo)
 from Iuno.shop.Util import createCheckValue
 
 _PaymentDetailsView = get_class('checkout.views', 'PaymentDetailsView')
@@ -1756,19 +1756,21 @@ class ATMFillView(generic.View):
 
     def get(self, request, *args, **kwargs):
         order = self.getOrder(request, *args, **kwargs)
-        
+        bank, account = getATMInfo()
         return render(
             request, 
             "shop/payment/FillAccount.html",
             {
                 'order': order,
+                'bank': bank,
+                'account': account,
             }
         )
         
     def post(self, request, *args, **kwargs):
         order = self.getOrder(request, *args, **kwargs)
         code = request.POST.get('account', None)
-        
+        bank, account = getATMInfo()
         if code and len(code) == 5: 
             # 帳號限制要5碼
             order.setATMCode(code)
@@ -1783,6 +1785,8 @@ class ATMFillView(generic.View):
             "shop/payment/FillAccount.html",
             {
                 'order': order,
+                'bank': bank,
+                'account': account,
             }
         )
         
